#[non_exhaustive]pub enum EcError {
BadBinaryMagic,
BadBlobMagic,
Malformed,
BufferTooSmall,
NotFound,
}Expand description
Errors returned by EcBinary operations.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
BadBinaryMagic
The container does not start with BINARY_MAGIC.
BadBlobMagic
The blob section is missing or does not start with BLOB_MAGIC.
Malformed
A section offset in the container header is out of bounds or misaligned.
BufferTooSmall
The destination buffer is too small for the blob.
NotFound
The requested relocation/patch index or identifier does not exist.